#!/usr/bin/python3

#importing python packages

import numpy as np
import copy
import matplotlib.pyplot as plt
import scipy.optimize as opt
import pandas as pd
from scipy import constants as const

#defining constants

T0 = 2459279.662465278 #JD of the trigger
d=86400 #length of 1 day in sec
f_names = []
corr_AB = [0,0,0.21,0.45,-0.08] # AB Corrections values
corr_ext = [0.14,0.14,0.136,0.099,0.193] # Galactic extinction values
m_gal = 24.5

#Input parameters for fit

p0 = [1.3,0.5,1,1,2,276,1e3,2e3,1e5,0.05,0.05,0.05,16.5]
fit_params = ['alpha1','alpha2','alpha3','alpha4','alpha5','Tb1','Tb2','Tb3','Tb4','cC','cR','cI','M0']
fix_params = ['G1','G2','G3','G4','beta']
fix_values = [0.01,0.01,0.01,0.05,0]

p0_freq = [10, 1]

p0_rtg = [1.3,2,16.5]
fit_params_rtg = ['alpha1','alpha2','M0']
fix_params_rtg = ['G1','Tb1']
fix_values_rtg = [0.1,2e3]
#Unused alternative fiting options

#p0 = [1.3,0.5,1.9,1,276,2e3,1e5,0.05,0.05,0.05,16.5]
#fit_params = ['alpha1','alpha2','alpha3','alpha4','Tb1','Tb2','Tb3','cC','cR','cI','M0']
#fix_params = ['G1','G2','G3','beta']
#fix_values = [0.01,0.1,0.1,0]

#p0 = [1.3,0.5,1.9,1,276,2e3,1e5,0.01,0.1,0.1,0.05,0.05,0.05,16.5]
#fit_params = ['alpha1','alpha2','alpha3','alpha4','Tb1','Tb2','Tb3','G1','G2','G3','cC','cR','cI','M0']
#fix_params = ['beta']
#fix_values = [0]

#p0 = [1.3,0.5,1.9,1,1,276,2e3,1e5,1.3e3,0.01,0.1,0.1,0.1,0.05,0.05,0.05,16.5]
#fit_params = ['alpha1','alpha2','alpha3','alpha4','alpha5','Tb1','Tb2','Tb3','Tb4','G1','G2','G3','G4','cC','cR','cI','M0']
#fix_params = ['beta']
#fix_values = [0]

#Defining the Filter class for simple access to filter properties

class Filter:
    def __init__(self,name,index,lambda_eff,gal_ext,ab_corr,gal_mag):
        self.name = name
        self.index = index
        self.lambda_eff = lambda_eff
        self.gal_ext = gal_ext
        self.ab_corr = ab_corr
        self.gal_mag = gal_mag
    def freq(self):
        f = const.speed_of_light/self.lambda_eff
        return f

#Loading the AsI CAS data format

def add_data(path):
    dat = pd.read_table(path,sep='\s+',engine='python', header=None,comment='#', usecols=[0,1,4,5,6], skip_blank_lines=True)
    temp_data = pd.DataFrame(data=None,columns=['t_eff','mag_eff','mag_err','filter'])
    temp_data['t_eff'] = dat[0]
    temp_data['mag_eff'] = -2.5*np.log10(10**(-0.4*dat[1])-10**(-0.4*m_gal))
    temp_data['mag_err'] = dat[4]-dat[5] #calculation of mag_err from mag_min and mag_max values
    for i in range(len(dat)):
        if i < 42:
            temp_data.at[i,'filter'] = 0 #clear
        elif i < 47:
            temp_data.at[i,'filter'] = 2 #R
        elif i < 57:
            temp_data.at[i,'filter'] = 1 #r
        else:
            temp_data.at[i,'filter'] = 0 #clear
    for i in range(5):
        temp_data.loc[temp_data['filter']==i,'mag_eff']+=(corr_AB[i]-corr_ext[i]) #performing the filter AB and gal ext correction
    return temp_data

#Loading the GCN data format

def add_data_extra(path):
    dat = pd.read_csv(path,sep='\s+',engine='python',header=None,comment='#',skip_blank_lines=True)
    temp_data = pd.DataFrame(data=None,columns=['t_eff','mag_eff','mag_err','filter','freq'])
    temp_data['t_eff'] = dat[0]+dat[1]/2 #calculation of t_eff from t_start and exp length
    temp_data['mag_eff'] = -2.5*np.log10(10**(-0.4*dat[2])-10**(-0.4*m_gal))
    temp_data['mag_err'] = dat[3]
    temp_data['filter'] = dat[4]
    for i in range(5):
        temp_data.loc[temp_data['filter']==i,'mag_eff']+=(corr_AB[i]-corr_ext[i])
    return temp_data

def add_rtg_data(path):
    dat = pd.read_csv(path, sep='\s+',engine='python',header=None,skip_blank_lines=True)
    temp_data = pd.DataFrame(data=None,columns=['t_eff','freq','mag_eff','mag_err'])
    temp_data['t_eff'] = dat[0]
    temp_data['freq'] = 2.418e18
    temp_data['mag_eff'] = 8.9-2.5*np.log10(dat[3])
    temp_data['mag_err'] = 1.091*(dat[4]-dat[5])/dat[3]
    return temp_data

def add_gama_data(path):
    dat = pd.read_csv(path, sep='\s+',engine='python',header=None,skip_blank_lines=True)
    temp_data = pd.DataFrame(data=None,columns=['t_eff','mag_eff','mag_eff_2','mag_err'])
    times = []
    intensities_weighted = []
    errors = []
    intensities = []
    for i in range(len(dat)//18):
        i_b = 18*i
        i_e = i_b+18
        times.append(np.average(dat[0][i_b:i_e]))
        intensities.append(np.average(dat[3][i_b:i_e]))
        intensities_weighted.append(np.average(dat[3][i_b:i_e],weights=1/dat[4][i_b:i_e]))
        errors.append(np.average(2*dat[4][i_b:i_e])/np.sqrt(18))
    temp_data['t_eff'] = times
    temp_data['mag_eff'] = intensities
    temp_data['mag_eff_2'] = intensities_weighted
    temp_data['mag_err'] = errors
    return temp_data
#Defining the support functions

def h(a,b):
    return a/2+b/2*np.sqrt(1+a**2/b**2)
def zip_params(x):
    all_params = fit_params + fix_params
    all_values = np.concatenate((x,np.array(fix_values)))
    return zip(all_params,all_values)
def zip_params_rtg(x):
    all_params = fit_params_rtg + fix_params_rtg
    all_values = np.concatenate((x,np.array(fix_values_rtg)))
    return zip(all_params,all_values)
def get_value(name,obj):
    return df[df['name'] == name][obj].item()
def print_model(x,df):
    print(df)
    for param,val in zip(fix_params,fix_values):
        print("\t%10s%10.3f"%(param,val))

#Defining the model

def model_test(x,y,p):
    #x represents time whereas y frequency, p are fit parameters
    model = 0
    for param,val in zip_params(p):
        if param == 'M0':
            M0 = val
        if param == 'alpha1':
            alpha1 = val
        if param == 'alpha2':
            alpha2 = val
        if param == 'alpha3':
            alpha3 = val
        if param == 'alpha4':
            alpha4 = val
        if param == 'alpha5':
            alpha5 = val
        if param == 'Tb1':
            Tb1 = val
        if param == 'Tb2':
            Tb2 = val
        if param == 'Tb3':
            Tb3 = val
        if param == 'Tb4':
            Tb4 = val
        if param == 'G1':
            G1 = val
        if param == 'G2':
            G2 = val
        if param == 'G3':
            G3 = val
        if param == 'G4':
            G4 = val
        if param == 'beta':
            beta = val
        if param == 'cC':
            cC = val
        if param == 'cR':
            cR = val
        if param == 'cI':
            cI = val
    model += M0
    model += alpha1*2.5*np.log10(x/Tb1)
    model += 2.5*(alpha2-alpha1)*h(np.log10(x/Tb1),G1)
    model += 2.5*(alpha3-alpha2)*h(np.log10(x/Tb2),G2)
    model += 2.5*(alpha4-alpha3)*h(np.log10(x/Tb3),G3)
    model += 2.5*(alpha5-alpha4)*h(np.log10(x/Tb4),G4)
    #model += 2.5*beta*np.log10(y/filter_r.freq())
    model[y==4e14] += cC
    model[y==428274940000000.0] += cR
    model[y<4e14] += cI
    return model


def model_test_rtg(x,y,p):
    #x represents time whereas y frequency, p are fit parameters
    model = 0
    for param,val in zip_params_rtg(p):
        if param == 'M0':
            M0 = val
        if param == 'alpha1':
            alpha1 = val
        if param == 'alpha2':
            alpha2 = val
        if param == 'alpha3':
            alpha3 = val
        if param == 'alpha4':
            alpha4 = val
        if param == 'alpha5':
            alpha5 = val
        if param == 'Tb1':
            Tb1 = val
        if param == 'Tb2':
            Tb2 = val
        if param == 'Tb3':
            Tb3 = val
        if param == 'Tb4':
            Tb4 = val
        if param == 'G1':
            G1 = val
        if param == 'G2':
            G2 = val
        if param == 'G3':
            G3 = val
        if param == 'G4':
            G4 = val
        if param == 'beta':
            beta = val
        if param == 'cC':
            cC = val
        if param == 'cR':
            cR = val
        if param == 'cI':
            cI = val
    model += M0
    model += alpha1*2.5*np.log10(x/Tb1)
    model += 2.5*(alpha2-alpha1)*h(np.log10(x/Tb1),G1)
    #model += 2.5*(alpha3-alpha2)*h(np.log10(x/Tb2),G2)
    #model += 2.5*(alpha4-alpha3)*h(np.log10(x/Tb3),G3)
    #model += 2.5*(alpha5-alpha4)*h(np.log10(x/Tb4),G4)
    #model += 2.5*beta*np.log10(y/filter_r.freq())
    #model[y==4e14] += cC
    #model[y==428274940000000.0] += cR
    #model[y<4e14] += cI
    return model

#Defining functions for optimization

def delinear(x):
    return np.sign(x)*np.sqrt(np.log1p(x**2))

def residuals(p,x,y,z,mag_err):
    residual = (z-model_test(x,y,p))/mag_err
    return delinear(residual)

def residuals_rtg(p,x,y,z,mag_err):
    residual = (z-model_test_rtg(x,y,p))/mag_err
    return delinear(residual)
#Unused alternative models

#def model_1(x,M0,alpha1,Tb1):
#    return M0 + alpha1*2.5*np.log10(x/Tb1)
#def model_2(x,M0,alpha1,alpha2,Tb1,G1):
#    return M0 + 2.5*(alpha2)*h(np.log10(x/Tb1),G1)
#def model_3(x,alpha1,alpha2,alpha3,Tb2,G2):
#    return 15+2.5*(alpha3)*h(np.log10(x/Tb2),G2)

#Filter definitions

def model_freq(x,p_freq):
    return p_freq[0]+2.5*p_freq[1]*np.log10(x/filter_r.freq())
def residuals_freq(p,x,y):
    return y - model_freq(x,p)

filter_C = Filter('C',0,661e-9,0.140,0,24.6)
filter_r = Filter('r',1,623e-9,0.140,0,24.6)
filter_R = Filter('R',2,700e-9,0.136,0.21,24.6)
filter_I = Filter('I',3,900e-9,0.099,0.45,24.6)
filter_g = Filter('g',4,477e-9,0.193,0,24.6)

#Reading the data

final_data = add_data('210306A-redo.dat')
final_data = final_data.append(add_data_extra('gcn.dat'))
for i in range(4):
    fls = [4e14, filter_r.freq(), filter_R.freq(), filter_I.freq()] #adding frequency to the dataframe
    final_data.loc[final_data['filter']==i,'freq']=fls[i] #converting filter caption to filter index
rtg_data = add_rtg_data('xray.txt')
gama_data = add_gama_data('gama.txt')

fls_fit = [filter_r.freq()]
print(gama_data)

#Control mechanism

#print(final_data)
final_data.to_csv('data_corr.csv')

#Performing the fit

inp = np.array([final_data['t_eff'],final_data['freq'],final_data['mag_eff'],final_data['mag_err']],dtype=np.float64())
res = opt.least_squares(residuals,p0,args=inp)
df = pd.DataFrame(list(zip(fit_params,res.x)),columns=['name','value'])
cov = np.linalg.inv(res.jac.T.dot(res.jac))
df['error'] = np.sqrt(np.diagonal(cov))

inp_rtg = np.array([rtg_data['t_eff'],rtg_data['freq'], rtg_data['mag_eff'],rtg_data['mag_err']],dtype=np.float64())
res_rtg = opt.least_squares(residuals_rtg,p0_rtg,args=inp_rtg)
df_rtg = pd.DataFrame(list(zip(fit_params_rtg,res_rtg.x)),columns=['name','value'])
cov_rtg = np.linalg.inv(res_rtg.jac.T.dot(res_rtg.jac))
df_rtg['error'] = np.sqrt(np.diagonal(cov_rtg))

#Printing the results to console

print('===== Curve 1 =====')
print_model(res.x,df)
print('rtg',res_rtg.x)
print('===== Curve 2 =====')
print_model(res_rtg.x,df_rtg)

#Unused graphing

#model_filter_2 = [0]*50
#x_model2 = np.linspace(np.min(x2[0]),np.max(x2[0]))
#y_model2 = model([x_model2,model_filter_2],res2.x)
#plt.plot(x_model2, y_model2, color='black',linestyle='--')
#for i in range(5):
#    l = ['g','r','orange','m','gray']
#    caps =['Clear','r','R','I','g']
#    ax.errorbar(final_data.loc[final_data['filter']==i, 't_eff'],2.5*res.x[8]*np.log10(np.array(final_data['freq'],dtype=np.float64)/filter_r.freq())+final_data.loc[final_data['filter']==i, 'mag_eff'],fmt='o',yerr=final_data.loc[final_data['filter']==i, 'mag_err']/2, color=l[i],ms=5,label=caps[i])

#Modelovani zavislosti jasnosti v case
x_model = 10**(np.linspace(np.log10(np.min(inp[0])),np.log10(np.max(inp[0])),num=len(final_data)))
freq_model = np.array(len(final_data)*[filter_r.freq()])
y_model = model_test(x_model,freq_model,res.x)


x_model_rtg = 10**(np.linspace(np.log10(np.min(inp_rtg[0])),np.log10(np.max(inp_rtg[0])),num=len(final_data)))
freq_model_rtg = np.array(len(rtg_data)*2.418e18)
y_model_rtg = model_test_rtg(x_model_rtg,freq_model_rtg,res_rtg.x)

#odbarveni dat zavislosti jasnosti na case pomoci fitnuteho koeficientu beta
ration =np.array(final_data['freq']/filter_r.freq(),dtype=np.float64)

#testy
#fig,ax = plt.subplots()

#plt.show()
res_freq = copy.deepcopy(res.x)
res_freq[-2] = 0
res_freq[-3] = 0
res_freq[-4] = 0
res_freq_2 = copy.deepcopy(res_freq)
res_freq_2[-1] = 0
#Vykresleni zavislosti jasnosti na case

inspect_t_2 = 400
inspect_t = 40000

x_model2 = 10**np.linspace(np.log10(np.min(inp[1])),np.log10(np.max(inp[1])),num=len(final_data))
y_model2 = model_test(np.array([inspect_t]*len(fls_fit)),np.array(fls_fit),res.x) #model v case inspect_t
y_model2_o = model_test(np.array([inspect_t_2]*len(fls)),np.array(fls),res.x) #model v case inspect_t
delta_mag = model_test(np.array([inspect_t]),np.array([filter_r.freq()]),res_freq_2)
y_model2_2 = model_test(np.array([inspect_t_2]*len(fls_fit)),np.array(fls_fit),res.x) #model v case inspect_t_2
delta_mag_2 = model_test(np.array([inspect_t_2]),np.array([filter_r.freq()]),res_freq_2)
y_model2_data = model_test(inp[0],inp[1],res_freq_2) #modelovani bez ohledu na frekvenci

x_model2_rtg = [2.418e18]
y_model2_rtg = model_test_rtg(np.array([inspect_t]),2.418e18,res_rtg.x) #model v case Tb1
y_model2_rtg_2 = model_test_rtg(np.array([inspect_t_2]),2.418e18,res_rtg.x) #model v case Tb1


freq_opt_o = np.array([fls, y_model2_o], dtype=np.float64())
result_freq_o = opt.least_squares(residuals_freq,p0_freq, args=freq_opt_o)
cov_freq_o = np.linalg.inv(result_freq_o.jac.T.dot(result_freq_o.jac))
error_freq_o = np.sqrt(np.diagonal(cov_freq_o))

freq_rtg_array = np.array([x_model2_rtg, y_model2_rtg], dtype = np.float64())
freq_opt_array = np.array([fls_fit, y_model2], dtype=np.float64())
inp_freq = np.concatenate((freq_opt_array, freq_rtg_array), axis=1)
result_freq = opt.least_squares(residuals_freq,p0_freq, args=inp_freq)
cov_freq = np.linalg.inv(result_freq.jac.T.dot(result_freq.jac))
error_freq = np.sqrt(np.diagonal(cov_freq))

freq_rtg_array_2 = np.array([x_model2_rtg, y_model2_rtg_2], dtype = np.float64())
freq_opt_array_2 = np.array([fls_fit, y_model2_2], dtype=np.float64())
inp_freq_2 = np.concatenate((freq_opt_array_2, freq_rtg_array_2), axis=1)
result_freq_2 = opt.least_squares(residuals_freq,p0_freq, args=inp_freq_2)
cov_freq_2 = np.linalg.inv(result_freq_2.jac.T.dot(result_freq_2.jac))
error_freq_2 = np.sqrt(np.diagonal(cov_freq_2))
print('Spectral index')
#print(result_freq_o.x,error_freq_o)
print(result_freq.x,error_freq)
print(result_freq_2.x,error_freq_2)

print(res_freq)
freq_beta_model = []
freq_beta_model_2 = []
for i,j in zip(inp_freq[0],inp_freq_2[0]):
    freq_beta_model.append(model_freq(i, result_freq.x))
    freq_beta_model_2.append(model_freq(j, result_freq_2.x))
freq_beta_model_o = model_freq(np.array([fls]), result_freq_o.x)
#Creating the plots

fig,ax = plt.subplots()
rtg_time = rtg_data['t_eff']
rtg_mag = rtg_data['mag_eff']
rtg_error = rtg_data['mag_err']/2
dmag = res_rtg.x[-1]-res.x[-1]-0.6
ax.errorbar(rtg_time, rtg_mag-dmag, yerr=rtg_error,fmt='o',ms=3,color='blue', label='RTG')
ax.plot(x_model_rtg, y_model_rtg-dmag, color='k',linestyle='--',label='model rtg')
ax.plot(x_model, y_model, color='r',linestyle='dotted', label='optika model')
for i in range(4):
    l = ['k','r','orange','m']
    caps =['C','r','R','I']
    input_time = final_data.loc[final_data['filter']==i, 't_eff']
    input_freq = final_data.loc[final_data['filter']==i, 'freq']
    input_mag = final_data.loc[final_data['filter']==i, 'mag_eff']
    input_mag_err = final_data.loc[final_data['filter']==i, 'mag_err']/2
    ax.errorbar(input_time,input_mag+model_test(input_time,input_freq,res_freq)-model_test(input_time,input_freq,res.x),yerr=input_mag_err,fmt='o',color=l[i],ms=5,label=caps[i])
ax.invert_yaxis()
ax.set_xlabel('Čas po alertu [s]')
ax.set_ylabel('Jasnost [mag]')
ax.tick_params(which = 'both',bottom=True,top=True,left=True,right=True)
ax.legend()
ax.set_xscale('log')
plt.savefig('lc.png',dpi=400)


fig,ax = plt.subplots()
dmag = res_rtg.x[-1]-res.x[-1]-0.5
#ax.plot(x_model_rtg, y_model_rtg-dmag, color='k',linestyle='--',label='model rtg')
ax.plot(x_model, (y_model-y_model_rtg+dmag)/(-2.5*np.log10(x_model))+0.45, color='r',linestyle='dotted', label='Model beta')
ax.set_xlabel('Čas po alertu [s]')
ax.set_ylabel('Beta')
ax.tick_params(which = 'both',bottom=True,top=True,left=True,right=True)
ax.legend()
ax.set_xscale('log')
plt.savefig('beta.png',dpi=400)

fig,ax = plt.subplots()
ax.plot(x_model, y_model, color='r',linestyle='dotted', label='optika model')
for i in range(4):
    l = ['k','r','orange','m']
    caps =['C','r','R','I']
    input_time = final_data.loc[final_data['filter']==i, 't_eff']
    input_freq = final_data.loc[final_data['filter']==i, 'freq']
    input_mag = final_data.loc[final_data['filter']==i, 'mag_eff']
    input_mag_err = final_data.loc[final_data['filter']==i, 'mag_err']/2
    ax.errorbar(input_time,input_mag+model_test(input_time,input_freq,res_freq)-model_test(input_time,input_freq,res.x),yerr=input_mag_err,fmt='o',color=l[i],ms=5,label=caps[i])
ax.invert_yaxis()
ax.set_xlabel('Čas po alertu [s]')
ax.set_ylabel('Jasnost [mag]')
ax.tick_params(which = 'both',bottom=True,top=True,left=True,right=True)
ax.legend()
ax.set_xscale('log')
plt.savefig('lc_optic.png',dpi=400)


fig,ax = plt.subplots()
rtg_time = rtg_data['t_eff']
rtg_mag = rtg_data['mag_eff']
rtg_error = rtg_data['mag_err']/2
dmag = res_rtg.x[-1]-res.x[-1]
ax.errorbar(rtg_time, rtg_mag, yerr=rtg_error,fmt='o',ms=3,color='blue', label='RTG')
ax.plot(x_model_rtg, y_model_rtg, color='k',linestyle='--',label='model rtg')
ax.invert_yaxis()
ax.set_xlabel('Čas po alertu [s]')
ax.set_ylabel('Jasnost [mag]')
ax.tick_params(which = 'both',bottom=True,top=True,left=True,right=True)
ax.legend()
ax.set_xscale('log')
plt.savefig('lc_rtg.png',dpi=400)

fig,ax = plt.subplots()
#ax.errorbar(gama_data['t_eff'], gama_data['mag_eff'], yerr=gama_data['mag_err']/2,fmt='o',ms=3,color='k', label='BAT data')
ax.errorbar(gama_data['t_eff'], gama_data['mag_eff_2'], yerr=gama_data['mag_err']/2,fmt='o',ms=3,color='k', label='BAT data vážená')
ax.set_xlabel('Čas po začátku snímání [s]')
ax.set_ylabel('Intenzita [Jy] - 10 keV')
ax.tick_params(which = 'both',bottom=True,top=True,left=True,right=True)
ax.legend()
plt.savefig('gama.png',dpi=400)

fig,ax = plt.subplots()
ax.scatter(x_model2_rtg, y_model2_rtg_2, label='Model RTG 400 s', marker='o', color='black')
ax.scatter(x_model2_rtg, y_model2_rtg, label='Model RTG 40000 s', marker='o', color='blue')
#ax.scatter(inp[1],inp[2]-y_model2_data+delta_mag,label='Data',marker='x',color='k')
ax.scatter(fls_fit,y_model2_2, color='k',label='Model optika v t = 400 s', marker='+')
ax.scatter(fls_fit,y_model2,color='blue',label='Model optika v t = 40 000 s',marker='+')
ax.plot(inp_freq_2[0],freq_beta_model_2, color='r', label='FIT 400 s', linestyle='dotted',linewidth=2)
ax.plot(inp_freq[0], freq_beta_model, color='r', label='FIT 40 000 s', linestyle='--', linewidth=2)
ax.invert_yaxis()
ax.set_xlabel('frekvence [Hz]')
ax.set_ylabel('Jasnost [mag]')
ax.tick_params(which = 'both',bottom=True,top=True,left=True,right=True)
ax.legend()
ax.set_xscale('log')
plt.savefig('freq.png',dpi=400)
#ax[0,1].set_title('Závislost jasnosti na frekvenci záblesku GRB210306A')


fig,ax = plt.subplots()
#ax.scatter(inp[1],inp[2]-y_model2_data+delta_mag,label='Data',marker='x',color='k')
ax.scatter(fls,y_model2_o, color='g',label='Model optika v t = 400 s', marker='o')
ax.plot(fls, freq_beta_model_o[0], color='r', label='FIT', linestyle='dotted', linewidth=2)
ax.invert_yaxis()
ax.set_xlabel('frekvence [Hz]')
ax.set_ylabel('Jasnost [mag]')
ax.tick_params(which = 'both',bottom=True,top=True,left=True,right=True, labelsize=7)
ax.legend()
ax.set_xscale('log')
plt.savefig('opt_freq_2.png',dpi=400)


fig,ax = plt.subplots()
ax.scatter(inp[0], residuals(res.x,inp[0],inp[1],inp[2],inp[3]),label='Data',marker='x',color='k')
ax.invert_yaxis()
ax.set_xlabel('Čas po alertu [s]')
ax.set_ylabel('Modifikovaná odchylka [mag]')
ax.tick_params(which = 'both',bottom=True,top=True,left=True,right=True)
ax.legend()
ax.set_xscale('log')
#ax.set_title('Rozložení chyb světelné křivky')
plt.savefig('error_lc_opt.png',dpi=400)

fig,ax = plt.subplots()
ax.scatter(inp_rtg[0], residuals_rtg(res_rtg.x,inp_rtg[0],inp_rtg[1],inp_rtg[2],inp_rtg[3]),label='Data',marker='x',color='b')
ax.invert_yaxis()
ax.set_xlabel('Čas po alertu [s]')
ax.set_ylabel('Modifikovaná odchylka [mag]')
ax.tick_params(which = 'both',bottom=True,top=True,left=True,right=True)
ax.legend()
ax.set_xscale('log')
#ax.set_title('Rozložení chyb světelné křivky')
plt.savefig('error_lc_rtg.png',dpi=400)

fig,ax = plt.subplots()
plt.savefig('error_lc')
ax.scatter(inp[1], residuals(res.x,inp[0],inp[1],inp[2],inp[3]),label='Data',marker='x',color='k')
#ax.set_ylim(ax.get_ylim()[::-1])
ax.invert_yaxis()
ax.set_xlabel('frekvence [Hz]')
ax.set_ylabel('Modifikovaná odchylka [mag]')
ax.tick_params(which = 'both',bottom=True,top=True,left=True,right=True,labelsize=7)
ax.legend()
ax.set_xscale('log')
#ax.set_title('Rozložení chyb v závislosti na frekvenci')
plt.savefig('error_freq',dpi=400)
